@@ -61,9 +61,9 @@ def prepare_test(production_name, job_name):
         "application_version": application_version,
         "bk_query": job_data["input"]["bk_query"],
     }
-    cookies = cern_sso.sign_in(ANA_PROD_HOST)
     resp = requests.get(
-        urlunparse(ANA_PROD_WEB_URL + ("", urlencode(params), "")), cookies=cookies
+        urlunparse(ANA_PROD_WEB_URL + ("", urlencode(params), "")),
+        cookies=cern_sso.sign_in(ANA_PROD_HOST),
     )
     if not resp.ok:
         click.secho(resp.text, fg="red")
@@ -121,10 +121,9 @@ def prepare_reproduce(pipeline_id, production_name, job_name, test_id="latest"):
         fg="green",
     )
 
-    cookies = cern_sso.sign_in(ANA_PROD_HOST)
     resp = requests.get(
         f"{ANA_PROD_HOST}/dynamic/{pipeline_id}/{production_name}/{job_name}/{test_id}/reproduce_locally.json",
-        cookies=cookies,
+        cookies=cern_sso.sign_in(ANA_PROD_HOST),
     )
     if not resp.ok:
         click.secho(resp.text, fg="red")
@@ -136,7 +135,7 @@ def prepare_reproduce(pipeline_id, production_name, job_name, test_id="latest"):
     click.secho(f"Cloning {data['git_repo']}", fg="green")
     subprocess.check_call(["git", "clone", data["git_repo"], tmp_dir])
 
-    click.echo(f"Running test in {tmp_dir}")
+    click.secho(f"Running test in {tmp_dir}", fg="green")
     os.chdir(tmp_dir)
 
     click.secho(f"Checking out {data['revision']}", fg="green")
